@@ -6,9 +6,10 @@
  * Please consult the license documentation provided alongside
  * this program the details of the active license.
  */
-use crate::data::table::VegaFusionTable;
+use crate::data::dataset::VegaFusionDataset;
 use crate::error::{Result, ResultWithContext, VegaFusionError};
-use crate::proto::gen::tasks::Task;
+use crate::proto::gen::tasks::{Task, TzConfig};
+use crate::spec::axis::AxisSpec;
 use crate::spec::data::DataSpec;
 use crate::spec::mark::MarkSpec;
 use crate::spec::scale::ScaleSpec;
@@ -42,6 +43,9 @@ pub struct ChartSpec {
     #[serde(default, skip_serializing_if = "Vec::is_empty")]
     pub scales: Vec<ScaleSpec>,
 
+    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    pub axes: Vec<AxisSpec>,
+
     #[serde(skip_serializing_if = "Option::is_none")]
     pub title: Option<TitleSpec>,
 
@@ -66,6 +70,9 @@ impl ChartSpec {
         for scale in &self.scales {
             visitor.visit_scale(scale, &scope)?;
         }
+        for axis in &self.axes {
+            visitor.visit_axis(axis, &scope)?;
+        }
         for signal in &self.signals {
             visitor.visit_signal(signal, &scope)?;
         }
@@ -102,6 +109,9 @@ impl ChartSpec {
         for scale in &mut self.scales {
             visitor.visit_scale(scale, &scope)?;
         }
+        for axis in &mut self.axes {
+            visitor.visit_axis(axis, &scope)?;
+        }
         for signal in &mut self.signals {
             visitor.visit_signal(signal, &scope)?;
         }
@@ -134,10 +144,10 @@ impl ChartSpec {
 
     pub fn to_tasks(
         &self,
-        local_tz: &str,
-        inline_datasets: Option<HashMap<String, VegaFusionTable>>,
+        tz_config: &TzConfig,
+        datasets: &HashMap<String, VegaFusionDataset>,
     ) -> Result<Vec<Task>> {
-        let mut visitor = MakeTasksVisitor::new(local_tz, inline_datasets);
+        let mut visitor = MakeTasksVisitor::new(tz_config, datasets);
         self.walk(&mut visitor)?;
         Ok(visitor.tasks)
     }
@@ -312,6 +322,9 @@ pub trait ChartVisitor {
     fn visit_scale(&mut self, _scale: &ScaleSpec, _scope: &[u32]) -> Result<()> {
         Ok(())
     }
+    fn visit_axis(&mut self, _axis: &AxisSpec, _scope: &[u32]) -> Result<()> {
+        Ok(())
+    }
     fn visit_non_group_mark(&mut self, _mark: &MarkSpec, _scope: &[u32]) -> Result<()> {
         Ok(())
     }
@@ -333,6 +346,9 @@ pub trait MutChartVisitor {
     fn visit_scale(&mut self, _scale: &mut ScaleSpec, _scope: &[u32]) -> Result<()> {
         Ok(())
     }
+    fn visit_axis(&mut self, _axis: &mut AxisSpec, _scope: &[u32]) -> Result<()> {
+        Ok(())
+    }
     fn visit_non_group_mark(&mut self, _mark: &mut MarkSpec, _scope: &[u32]) -> Result<()> {
         Ok(())
     }
