@@ -6,6 +6,7 @@
  * Please consult the license documentation provided alongside
  * this program the details of the active license.
  */
+use crate::data::dataset::VegaFusionDataset;
 use crate::data::scalar::{ScalarValue, ScalarValueHelpers};
 use crate::data::table::VegaFusionTable;
 use crate::error::{Result, VegaFusionError};
@@ -13,7 +14,7 @@ use crate::expression::parser::parse;
 use crate::proto::gen::tasks::data_url_task::Url;
 use crate::proto::gen::tasks::{
     scan_url_format, DataSourceTask, DataUrlTask, DataValuesTask, ParseFieldSpec, ParseFieldSpecs,
-    ScanUrlFormat, Task, Variable,
+    ScanUrlFormat, Task, TzConfig, Variable,
 };
 use crate::proto::gen::transforms::TransformPipeline;
 use crate::spec::chart::{ChartSpec, ChartVisitor};
@@ -103,24 +104,24 @@ impl ChartVisitor for MakeTaskScopeVisitor {
 }
 
 /// For a spec that is fully supported on the server, collect tasks
-#[derive(Clone, Debug, Default)]
-pub struct MakeTasksVisitor {
+#[derive(Clone, Debug)]
+pub struct MakeTasksVisitor<'a> {
     pub tasks: Vec<Task>,
-    pub local_tz: String,
-    pub inline_datasets: HashMap<String, VegaFusionTable>,
+    pub tz_config: TzConfig,
+    pub datasets: &'a HashMap<String, VegaFusionDataset>,
 }
 
-impl MakeTasksVisitor {
-    pub fn new(tz: &str, inline_datasets: Option<HashMap<String, VegaFusionTable>>) -> Self {
+impl<'a> MakeTasksVisitor<'a> {
+    pub fn new(tz_config: &TzConfig, datasets: &'a HashMap<String, VegaFusionDataset>) -> Self {
         Self {
             tasks: Default::default(),
-            local_tz: tz.to_string(),
-            inline_datasets: inline_datasets.unwrap_or_default(),
+            tz_config: tz_config.clone(),
+            datasets,
         }
     }
 }
 
-impl ChartVisitor for MakeTasksVisitor {
+impl<'a> ChartVisitor for MakeTasksVisitor<'a> {
     fn visit_data(&mut self, data: &DataSpec, scope: &[u32]) -> Result<()> {
         let data_var = Variable::new_data(&data.name);
 
@@ -165,7 +166,7 @@ impl ChartVisitor for MakeTasksVisitor {
         };
 
         let task = if let Some(url) = &data.url {
-            let proto_url = match url {
+            let mut proto_url = match url {
                 StringOrSignalSpec::String(url) => Url::String(url.clone()),
                 StringOrSignalSpec::Signal(expr) => {
                     let url_expr = parse(&expr.signal)?;
@@ -173,30 +174,13 @@ impl ChartVisitor for MakeTasksVisitor {
                 }
             };
 
-            // Handle inline data
+            // Append fingerprint to URL that references an inline dataset
             if let Url::String(url) = &proto_url {
                 if let Some(inline_name) = url.strip_prefix("vegafusion+dataset://") {
                     let inline_name = inline_name.trim().to_string();
-                    return if let Some(inline_dataset) = self.inline_datasets.get(&inline_name) {
-                        let task = Task::new_data_values(
-                            data_var,
-                            scope,
-                            DataValuesTask {
-                                values: inline_dataset.to_ipc_bytes()?,
-                                format_type,
-                                pipeline,
-                            },
-                            &self.local_tz,
-                        );
-
-                        self.tasks.push(task);
-                        Ok(())
-                    } else {
-                        Err(VegaFusionError::internal(format!(
-                            "No inline dataset named {}",
-                            inline_name
-                        )))
-                    };
+                    if let Some(dataset) = self.datasets.get(&inline_name) {
+                        proto_url = Url::String(format!("{}#{}", url, dataset.fingerprint()));
+                    }
                 }
             }
 
@@ -209,7 +193,7 @@ impl ChartVisitor for MakeTasksVisitor {
                     pipeline,
                     url: Some(proto_url),
                 },
-                &self.local_tz,
+                &self.tz_config,
             )
         } else if let Some(source) = &data.source {
             Task::new_data_source(
@@ -219,7 +203,7 @@ impl ChartVisitor for MakeTasksVisitor {
                     source: source.clone(),
                     pipeline,
                 },
-                &self.local_tz,
+                &self.tz_config,
             )
         } else {
             let values_table = match data.values.as_ref() {
@@ -243,7 +227,7 @@ impl ChartVisitor for MakeTasksVisitor {
                         format_type,
                         pipeline,
                     },
-                    &self.local_tz,
+                    &self.tz_config,
                 )
             }
         };
@@ -259,7 +243,7 @@ impl ChartVisitor for MakeTasksVisitor {
             Task::new_value(signal_var, scope, value)
         } else if let Some(update) = &signal.update {
             let expression = parse(update)?;
-            Task::new_signal(signal_var, scope, expression, &self.local_tz)
+            Task::new_signal(signal_var, scope, expression, &self.tz_config)
         } else {
             return Err(VegaFusionError::internal(format!(
                 "Signal must have an initial value or an update expression: {:#?}",
@@ -562,6 +546,9 @@ impl<'a> ChartVisitor for InputVarsChartVisitor<'a> {
                 ScaleDomainSpec::FieldsReference(field_references) => {
                     references.extend(field_references.fields.clone());
                 }
+                ScaleDomainSpec::FieldsSignals(fields_signals) => {
+                    signals.extend(fields_signals.fields.clone());
+                }
                 ScaleDomainSpec::Signal(signal_expr) => {
                     signals.push(signal_expr.clone());
                 }
