@@ -10,7 +10,7 @@ use crate::error::VegaFusionError;
 use crate::proto::gen::tasks::Variable;
 use crate::proto::gen::transforms::transform::TransformKind;
 use crate::proto::gen::transforms::{
-    Aggregate, Bin, Collect, Extent, Filter, Formula, Project, Stack, TimeUnit,
+    Aggregate, Bin, Collect, Extent, Filter, Formula, Impute, Project, Stack, TimeUnit,
 };
 use crate::proto::gen::transforms::{JoinAggregate, Transform, Window};
 use crate::spec::transform::TransformSpec;
@@ -23,6 +23,7 @@ pub mod collect;
 pub mod extent;
 pub mod filter;
 pub mod formula;
+pub mod impute;
 pub mod joinaggregate;
 pub mod pipeline;
 pub mod project;
@@ -48,6 +49,7 @@ impl TryFrom<&TransformSpec> for TransformKind {
             TransformSpec::Window(tx_spec) => Self::Window(Window::try_new(tx_spec)?),
             TransformSpec::Project(tx_spec) => Self::Project(Project::try_new(tx_spec)?),
             TransformSpec::Stack(tx_spec) => Self::Stack(Stack::try_new(tx_spec)?),
+            TransformSpec::Impute(tx_spec) => Self::Impute(Impute::try_new(tx_spec)?),
             _ => {
                 return Err(VegaFusionError::parse(&format!(
                     "Unsupported transform: {:?}",
@@ -82,6 +84,7 @@ impl TransformKind {
             TransformKind::Window(tx) => tx,
             TransformKind::Project(tx) => tx,
             TransformKind::Stack(tx) => tx,
+            TransformKind::Impute(tx) => tx,
         }
     }
 }
